<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Reference Documentation

- **[claude-cli-stream-json.md](claude-cli-stream-json.md)** — parsing claude cli output, extracting metadata from stream-json, working with session_id, implementing stream-json parser
- **[toml-handling.md](toml-handling.md)** — reading TOML files, writing TOML files, generating TOML configuration, working with config.toml, working with pyproject.toml
